@@ -1,5 +1,5 @@
 /* idn.c	Command line interface to the library
- * Copyright (C) 2003  Simon Josefsson
+ * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -33,7 +33,7 @@
 
 #include "idn_cmd.h"
 
-#define GREETING "Copyright 2002, 2003 Simon Josefsson.\n"		\
+#define GREETING "Copyright 2002, 2003, 2004 Simon Josefsson.\n"	\
   "GNU Libidn comes with NO WARRANTY, to the extent permitted by law.\n" \
   "You may redistribute copies of GNU Libidn under the terms of\n"	\
   "the GNU Lesser General Public License.  For more information\n"	\
@@ -122,7 +122,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, "input[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "input[%d] = U+%04x\n", i, q[i]);
 	    }
 	  free (q);
 
@@ -151,7 +151,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, "output[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "output[%d] = U+%04x\n", i, q[i]);
 	    }
 	  free (q);
 
@@ -194,7 +194,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; i < len; i++)
-		fprintf (stderr, "input[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "input[%d] = U+%04x\n", i, q[i]);
 	    }
 
 	  len2 = BUFSIZ;
@@ -251,7 +251,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; i < len; i++)
-		fprintf (stderr, "output[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "output[%d] = U+%04x\n", i, q[i]);
 	    }
 
 	  q[len] = 0;
@@ -301,7 +301,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, "input[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "input[%d] = U+%04x\n", i, q[i]);
 	    }
 
 	  rc = idna_to_ascii_4z (q, &r,
@@ -321,7 +321,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; r[i]; i++)
-		fprintf (stderr, "output[%d] = U+%0.4x\n", i, r[i]);
+		fprintf (stderr, "output[%d] = U+%04x\n", i, r[i]);
 	    }
 
 	  fprintf (stdout, "%s\n", r);
@@ -352,7 +352,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, "input[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "input[%d] = U+%04x\n", i, q[i]);
 	    }
 	  free (q);
 
@@ -373,7 +373,7 @@ main (int argc, char *argv[])
 	    {
 	      size_t i;
 	      for (i = 0; q[i]; i++)
-		fprintf (stderr, "output[%d] = U+%0.4x\n", i, q[i]);
+		fprintf (stderr, "output[%d] = U+%04x\n", i, q[i]);
 	    }
 
 	  p = stringprep_ucs4_to_utf8 (q, -1, NULL, NULL);
